@@ -45,6 +45,9 @@ class UIElement:
     def handle_event(self, event: pygame.event.Event):
         pass
 
+    def update(self, delta_time: float):
+        pass
+
 class UIImage(UIElement):
     """
     A UI element for rendering images.
@@ -226,6 +229,10 @@ class Canvas:
         for element in self.elements:
             element.render(self.screen)
 
+    def update(self, dt: float):
+        for element in self.elements:
+            element.update(dt)
+
     def handle_event(self, event: pygame.event.Event):
         for element in self.elements:
             element.handle_event(event)
